@@ -191,6 +191,10 @@ def get_relationships(model):
     return list(model.__mapper__.relationships)
 
 
+def get_model_from_relationship(model, rel):
+    return getattr(model, rel).property.entity.entity
+
+
 def relationships(model, fmt=False):
     rels = model.__mapper__.relationships
     if fmt:
