@@ -40,7 +40,7 @@ class QueryBuffer:
 
         self.pagedquery = None
         self.queryargs: QueryStringProcessor = queryargs
-        self.data: [list, DeclarativeBase] = list()
+        self.data = list()
         self.fields: set = set()
         self.count: int = 0
         self.flags = ['Y', 'N', 'P']
@@ -52,6 +52,13 @@ class QueryBuffer:
         if auto:
             self.apply()
 
+    def __getattr__(self, f, *args, **kwargs):
+        def _query_function(operation, *args, **kwargs):
+            if hasattr(self.query, operation):
+                return getattr(self.query, operation)
+            raise NotImplementedError('This function is not available on the BaseQuery object.')
+        return _query_function(f, *args, **kwargs)
+
     @staticmethod
     def querystring():
         return QueryStringProcessor(dict(request.args))
@@ -85,6 +92,84 @@ class QueryBuffer:
         self.basequery = query
         return self.basequery
 
+    def build(self, query, queryargs, entity=None):
+        entity = entity or query._entity_zero().entity
+        base_fields = set(map(lambda x: x.key, entity.__mapper__.columns))
+        _relationships = set(map(lambda x: x.key, entity.__mapper__.relationships))
+        keys = columns(entity, strformat=True)
+        fields = base_fields.difference(set(queryargs.exclusions))
+
+        if queryargs.include:
+            fields = set()
+            for item in queryargs.include:
+                if not {item}.issubset(base_fields):
+                    raise HTTPBadRequest('{} is not a recognised attribute of this resource'.format(item))
+                fields.add(item)
+            self.fields = fields
+
+        if queryargs.rels:
+            if type(queryargs.rels) in [list, set]:
+                fields.union(set(relationships(entity)).difference(queryargs.rels))
+            elif queryargs.rels:
+                fields.union(_relationships)
+                queryargs.rels = _relationships
+
+        updated_rels = set()
+
+        if type(queryargs.rels) in [list, set]:
+            for item in queryargs.rels:
+                if self.check_key(item):
+                    pass
+                updated_rels.add(item)
+            queryargs.rels = updated_rels
+
+        if not queryargs.sortkey or queryargs.sortkey == '':
+            queryargs.sortkey = get_primary_key_field(entity).name
+
+        self.prepare_query(queryargs.include)
+
+        if queryargs.sortkey in keys:
+            column = getattr(entity, queryargs.sortkey, get_primary_key_field(entity))
+            if queryargs.descending and queryargs.sortkey in columns(entity, strformat=True):
+                query = query.order_by(desc(column))
+            else:
+                query = query.order_by(column)
+
+        filters = queryargs.filters
+        query, filters = self.check_relationship_filtering(query, filters)
+
+        setfilters = []
+
+        if getattr(queryargs, 'filterin', None):
+            for key, search in getattr(queryargs, 'filterin').items():
+                setfilters.append(getattr(entity, key).in_(search))
+                del filters[key]
+
+        query = query.filter(*setfilters)
+
+        try:
+            query = query.filter_by(**filters)
+        except InvalidRequestError as exc:
+            self.errors.append(str(exc))
+            # raise HTTPBadRequest(str(exc))
+
+        for key, value in queryargs.max:
+            query = query.filter(getattr(self.model, key) <= value)
+
+        for key, value in queryargs.min:
+            query = query.filter(getattr(self.model, key) >= value)
+
+        if queryargs.page:
+            query = query.paginate(queryargs.page, queryargs.pagesize or 50, False)
+            self.paginated = True
+            return query
+
+        default_field = getattr(self.model, self.model.__mapper__.primary_key[0].name)
+        query = query.group_by(default_field)
+        query = query.limit(self.queryargs.limit)
+        # self.basequery = self.basequery.options(load_only(*self.fields))
+        return query
+
     def apply(self, pending=False, inactive=False, query=None, entity=None):
         entity = entity or self.basequery._entity_zero()
         base_fields = set(map(lambda x: x.key, entity.column_attrs))
@@ -93,6 +178,9 @@ class QueryBuffer:
 
         self.fields = base_fields.difference(set(self.queryargs.exclusions))
         # Now detect whether we want relationships
+
+        # session.query(arti).join(arti, self.model.articles).filter(arti.active=='Y').order_by(desc(arti.created)).all()
+
         if self.queryargs.include:
             fields = set()
             for item in self.queryargs.include:
